# WSGI middleware for OAuth
[![Build Status](https://travis-ci.org/last-g/oauth_middleware.svg?branch=master)](https://travis-ci.org/last-g/oauth_middleware)

This is simple (not really) middleware based on flask_oauthlib that provides
full protection with oauth for your WSGI application.


Features
--------

* support for any WSGI based application
* web-based authentication
* basic auth with token authentication for scripts


Installation:
-------------

* `pip install oauth_middleware`

or

* just mention `oauth_middleware` in your requirements

